#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_tokodon_content_ui_Components_Emoji_EmojiDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_Emoji_EmojiGrid_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_Emoji_EmojiPicker_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_Emoji_EmojiTonesPicker_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_ClickableIdentityInfo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_FocusedImage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_InlineIdentityInfo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_PopupShadow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_ProfileHeader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_RoundedEffect_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_Sidebar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_TimelineView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_UserCard_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_QrCodeMaximizeComponent_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_BoostConfirmationDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_VideoPlayer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Components_ServerInformationCard_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_InitialSetup_SetupNotifications_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_InitialSetup_SetupPassword_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_InitialSetup_SetupWelcome_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_LoginFlow_BaseAuthorization_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_LoginFlow_BrowserAuthorization_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_LoginFlow_CodeAuthorization_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_LoginFlow_LoginIssuePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_LoginFlow_RegistrationPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_LoginFlow_RulesPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_LoginFlow_ServersPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_LoginFlow_WelcomePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ModerationTools_AccountToolPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ModerationTools_EmailBlockToolPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ModerationTools_FederationToolPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ModerationTools_IpRulePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ModerationTools_MainAccountToolPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ModerationTools_MainFederationToolPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ModerationTools_MainIpRulePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ModerationTools_MainReportToolPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ModerationTools_ModerationToolsView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ModerationTools_ReportToolPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Notifications_AccountWarningDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Notifications_GroupInteractionLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Notifications_MinimalPostDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Notifications_RelationshipSeveranceDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Notifications_ReportDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Notifications_UserInteractionLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Notifications_AnnualReportDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Notifications_FollowDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Notifications_UnknownNotificationDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_AccountPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_AccountsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_AppearancePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_EditProfilePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_ErrorLogPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_NetworkProxyPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_NotificationsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_ProfileEditor_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_SafetyPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_TokodonConfigurationView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_FiltersPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_EditFilterPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Settings_BlockedDomainsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_StatusComposer_EditorAttachmentGrid_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_StatusComposer_AttachmentInfoDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_StatusComposer_ComposerPoll_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_StatusComposer_EmojiDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_StatusComposer_StatusComposer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_StatusComposer_StatusPreview_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_StatusComposer_ScheduledPostsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_AttachmentGrid_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_AttachmentMenu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_InformationBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_InteractionButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_LinkMenu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_LinkPreview_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_MediaContainer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostContent_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostInfoBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostLayout_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostMenu_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostPoll_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostTags_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostInteractionLabel_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_VideoAttachment_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_QuotePost_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_AudioAttachment_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_FilterNotice_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_PostDelegate_ContentNotice_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_AccountHeader_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_AccountInfo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_AnnouncementsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ConversationDelegate_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ConversationPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_EditListPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ExplorePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_FollowingPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_FullScreenImage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_LanguageSelector_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ListsPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_Main_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ListTimelinePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_MastoPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_NotificationPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ReadMarker_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ReportDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_SearchField_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_SearchPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_SearchView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ShareDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_SocialGraphPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_StandaloneComposer_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ThreadPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_TimelinePage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_UserInfo_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ServerInformationPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_GenericServerInformationPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_AccountSwitchDialog_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_ShareAction_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _qt_qml_org_kde_tokodon_content_ui_LoginFlow_WebViewAuthorization_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/Emoji/EmojiDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_Emoji_EmojiDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/Emoji/EmojiGrid.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_Emoji_EmojiGrid_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/Emoji/EmojiPicker.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_Emoji_EmojiPicker_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/Emoji/EmojiTonesPicker.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_Emoji_EmojiTonesPicker_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/ClickableIdentityInfo.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_ClickableIdentityInfo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/FocusedImage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_FocusedImage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/InlineIdentityInfo.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_InlineIdentityInfo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/PopupShadow.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_PopupShadow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/ProfileHeader.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_ProfileHeader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/RoundedEffect.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_RoundedEffect_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/Sidebar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_Sidebar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/TimelineView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_TimelineView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/UserCard.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_UserCard_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/QrCodeMaximizeComponent.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_QrCodeMaximizeComponent_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/BoostConfirmationDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_BoostConfirmationDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/VideoPlayer.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_VideoPlayer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Components/ServerInformationCard.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Components_ServerInformationCard_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/InitialSetup/SetupNotifications.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_InitialSetup_SetupNotifications_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/InitialSetup/SetupPassword.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_InitialSetup_SetupPassword_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/InitialSetup/SetupWelcome.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_InitialSetup_SetupWelcome_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/LoginFlow/BaseAuthorization.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_LoginFlow_BaseAuthorization_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/LoginFlow/BrowserAuthorization.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_LoginFlow_BrowserAuthorization_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/LoginFlow/CodeAuthorization.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_LoginFlow_CodeAuthorization_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/LoginFlow/LoginIssuePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_LoginFlow_LoginIssuePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/LoginFlow/RegistrationPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_LoginFlow_RegistrationPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/LoginFlow/RulesPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_LoginFlow_RulesPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/LoginFlow/ServersPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_LoginFlow_ServersPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/LoginFlow/WelcomePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_LoginFlow_WelcomePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ModerationTools/AccountToolPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ModerationTools_AccountToolPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ModerationTools/EmailBlockToolPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ModerationTools_EmailBlockToolPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ModerationTools/FederationToolPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ModerationTools_FederationToolPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ModerationTools/IpRulePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ModerationTools_IpRulePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ModerationTools/MainAccountToolPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ModerationTools_MainAccountToolPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ModerationTools/MainFederationToolPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ModerationTools_MainFederationToolPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ModerationTools/MainIpRulePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ModerationTools_MainIpRulePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ModerationTools/MainReportToolPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ModerationTools_MainReportToolPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ModerationTools/ModerationToolsView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ModerationTools_ModerationToolsView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ModerationTools/ReportToolPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ModerationTools_ReportToolPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Notifications/AccountWarningDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Notifications_AccountWarningDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Notifications/GroupInteractionLabel.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Notifications_GroupInteractionLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Notifications/MinimalPostDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Notifications_MinimalPostDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Notifications/RelationshipSeveranceDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Notifications_RelationshipSeveranceDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Notifications/ReportDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Notifications_ReportDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Notifications/UserInteractionLabel.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Notifications_UserInteractionLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Notifications/AnnualReportDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Notifications_AnnualReportDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Notifications/FollowDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Notifications_FollowDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Notifications/UnknownNotificationDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Notifications_UnknownNotificationDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/AccountPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_AccountPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/AccountsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_AccountsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/AppearancePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_AppearancePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/EditProfilePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_EditProfilePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/ErrorLogPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_ErrorLogPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/NetworkProxyPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_NetworkProxyPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/NotificationsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_NotificationsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/ProfileEditor.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_ProfileEditor_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/SafetyPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_SafetyPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/TokodonConfigurationView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_TokodonConfigurationView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/FiltersPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_FiltersPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/EditFilterPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_EditFilterPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Settings/BlockedDomainsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Settings_BlockedDomainsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/StatusComposer/EditorAttachmentGrid.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_StatusComposer_EditorAttachmentGrid_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/StatusComposer/AttachmentInfoDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_StatusComposer_AttachmentInfoDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/StatusComposer/ComposerPoll.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_StatusComposer_ComposerPoll_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/StatusComposer/EmojiDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_StatusComposer_EmojiDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/StatusComposer/StatusComposer.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_StatusComposer_StatusComposer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/StatusComposer/StatusPreview.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_StatusComposer_StatusPreview_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/StatusComposer/ScheduledPostsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_StatusComposer_ScheduledPostsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/AttachmentGrid.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_AttachmentGrid_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/AttachmentMenu.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_AttachmentMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/InformationBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_InformationBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/InteractionButton.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_InteractionButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/LinkMenu.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_LinkMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/LinkPreview.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_LinkPreview_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/MediaContainer.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_MediaContainer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/PostContent.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostContent_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/PostInfoBar.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostInfoBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/PostDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/PostLayout.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostLayout_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/PostMenu.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostMenu_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/PostPoll.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostPoll_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/PostTags.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostTags_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/PostInteractionLabel.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_PostInteractionLabel_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/VideoAttachment.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_VideoAttachment_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/QuotePost.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_QuotePost_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/AudioAttachment.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_AudioAttachment_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/FilterNotice.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_FilterNotice_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/PostDelegate/ContentNotice.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_PostDelegate_ContentNotice_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/AccountHeader.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_AccountHeader_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/AccountInfo.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_AccountInfo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/AnnouncementsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_AnnouncementsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ConversationDelegate.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ConversationDelegate_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ConversationPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ConversationPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/EditListPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_EditListPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ExplorePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ExplorePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/FollowingPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_FollowingPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/FullScreenImage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_FullScreenImage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/LanguageSelector.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_LanguageSelector_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ListsPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ListsPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/Main.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_Main_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ListTimelinePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ListTimelinePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/MastoPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_MastoPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/NotificationPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_NotificationPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ReadMarker.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ReadMarker_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ReportDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ReportDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/SearchField.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_SearchField_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/SearchPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_SearchPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/SearchView.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_SearchView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ShareDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ShareDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/SocialGraphPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_SocialGraphPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/StandaloneComposer.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_StandaloneComposer_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ThreadPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ThreadPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/TimelinePage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_TimelinePage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/UserInfo.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_UserInfo_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ServerInformationPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ServerInformationPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/GenericServerInformationPage.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_GenericServerInformationPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/AccountSwitchDialog.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_AccountSwitchDialog_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/ShareAction.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_ShareAction_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/qt/qml/org/kde/tokodon/content/ui/LoginFlow/WebViewAuthorization.qml"), &QmlCacheGeneratedCode::_qt_qml_org_kde_tokodon_content_ui_LoginFlow_WebViewAuthorization_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_tokodon_static)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_tokodon_static))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_tokodon_static)() {
    return 1;
}
