/****************************************************************************
** Meta object code from reading C++ file 'ipinfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../tokodon-26.04.0/src/admin/ipinfo.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ipinfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6IpInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto IpInfo::qt_create_metaobjectdata<qt_meta_tag_ZN6IpInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IpInfo",
        "QML.Element",
        "auto",
        "ipInfo",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Only for enums",
        "SeverityValues",
        "LimitSignUps",
        "BlockSignUps",
        "BlockAccess"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SeverityValues'
        QtMocHelpers::EnumData<enum SeverityValues>(8, 8, QMC::EnumFlags{}).add({
            {    9, SeverityValues::LimitSignUps },
            {   10, SeverityValues::BlockSignUps },
            {   11, SeverityValues::BlockAccess },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    1,    3 },
            {    4,    5 },
            {    6,    7 },
    });
    return QtMocHelpers::metaObjectData<IpInfo, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject IpInfo::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6IpInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6IpInfoE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6IpInfoE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
